==> serverless-cloudflare-workers-1.0.6.tgz: package/invoke/lib/invoke.js <==
/**
 * Copyright (c) 2018, Cloudflare. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *  3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
module.exports = {
  bakeEvent() {
    const functionObject = this.getFunctionObject();
    const { events } = functionObject;

    let bakedEvent = { url: "", headers: {}, method: "GET" };
    events.forEach(event => {
      const { http } = event;
      Object.keys(http).forEach(httpEvent => {
        if (httpEvent === "url") {
          console.log(http)
          let urlString = http[httpEvent];
          if (!urlString.startsWith("http://")) {
            urlString = "https://" + urlString;
          }
          bakedEvent.url = urlString;
        } else if (httpEvent == "headers") {
          Object.keys(http[httpEvent]).forEach(key => {
            const value = http[httpEvent][key];
            bakedEvent["headers"][key] = value;
          });
        } else {
          bakedEvent[httpEvent] = http[httpEvent];
        }
      });
    });
    return bakedEvent;
  }
};

==> serverless-cloudflare-workers-1.0.8.tgz: package/invoke/lib/invoke.js <==
/**
 * Copyright (c) 2018, Cloudflare. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *  3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
module.exports = {
  bakeEvent() {
    const functionObject = this.getFunctionObject();
    const { events } = functionObject;

    let bakedEvent = { url: "", headers: {}, method: "GET" };

    events.forEach(event => {
      const { http } = event;

      Object.keys(http).forEach(httpEvent => {
        if (httpEvent === "url") {
          let urlString = http[httpEvent];
          if (!urlString.startsWith("http://") && !urlString.startsWith("https://")) {
            urlString = "https://" + urlString;
          }
          if (this.options.querystring) {
            urlString += "?" + this.options.querystring;
          }
          bakedEvent.url = urlString;
        } else if (httpEvent == "headers") {
          Object.keys(http[httpEvent]).forEach(key => {
            const value = http[httpEvent][key];
            bakedEvent["headers"][key] = value;
          });
        } else {
          bakedEvent[httpEvent] = http[httpEvent];
        }
      });
    });
    return bakedEvent;
  }
};
